#include <stdlib.h>
#include <string.h>
#include "TBuffer.hh"
#include "TMemoryException.hh"

// Use a memory block size of 256 bytes
#define MEMORY_SIZE(n) ((n + 255) & ~255)


TBuffer::TBuffer ()
  : myMemory (0),
    myUsedMemory (0),
    myAvailMemory (0)
{
}


TBuffer::TBuffer (const TBuffer& buf)
{
  myMemory = 0;
  myUsedMemory = buf.myUsedMemory;
  myAvailMemory = buf.myAvailMemory;
  
  if (myAvailMemory)
    {
      myMemory = (char *)malloc (myAvailMemory);
      if (myMemory)
	memcpy (myMemory, buf.myMemory, myUsedMemory);
      else
	throw TMemoryException ();
    }
}


TBuffer::~TBuffer ()
{
  if (myMemory)
    free (myMemory);
}


void
TBuffer::Append (const char *cs, int n)
{
  int needed_mem = myUsedMemory + n;
  char *p;
  
  if (myAvailMemory < needed_mem)
    {
      int mem_size = MEMORY_SIZE (needed_mem);
      p = (char *)realloc (myMemory, mem_size);
      if (! p)
	throw TMemoryException ("Out of memory!");
      
      myMemory = p;
      myAvailMemory = mem_size;
    }
  
  memcpy (myMemory + myUsedMemory, cs, n);
  myUsedMemory += n;
}
