#ifndef _T_BUFFER_HH
#define _T_BUFFER_HH

#include "TString.hh"


/**
 * The TBuffer can be used as a storage container for arbitary
 * data. It is not immutable as the TString and does not contain
 * the typical string operations.
 *
 * @author Johan Bolmsjo <johan@nocrew.org>
 */

class TBuffer
{
public:
  
  /**
   * Construct an empty TBuffer.
   */
  TBuffer ();
  
  /**
   * Copy CTOR.
   */
  TBuffer (const TBuffer& buf);
  
  /**
   * Destruct TBuffer.
   */
  ~TBuffer ();
  
  /**
   * Append a copy of the null terminated string cs to buffer.
   */
  inline void Append (const char* cs)
  {
    Append (cs, TString::Length (cs));
  }
  
  /**
   * Append a copy of the first n bytes of cs to buffer.
   */
  void Append (const char* cs, int n);
  
  /**
   * Return the base pointer of the allocated memory.
   * Note that the pointer will not be vaild once the TBuffer goes out
   * of scope. Also it can be changed by other methods in the class.
   */
  inline char* Data () const { return myMemory; }
  
  /**
   * Clear the buffer.
   */
  void Clear () { myUsedMemory = 0; }
  
  /**
   *  Returns the length of the buffer (used memory).
   */
  inline int Length () const { return myUsedMemory; }
  
private:
  
  // Base pointer to memory
  char *myMemory;
  
  // Memory used
  int myUsedMemory;
  
  // Memory allocated
  int myAvailMemory;
};

#endif // _T_BUFFER_HH
