#include "universe.h"
#ifdef HAVE_POSTGRESQL

#include "TDBConnection.hh"


TDBResult*
TDBConnection::Execute (const TString &command)
{
  PGresult* result = PQexec (myConn, command.Data ());
  return new TDBResult (result);
}


TDBConnection::TDBConnection ()
  : myConn (0)
{
}


void
TDBConnection::Open (const TString &username,
		     const TString &password,
		     const TString &database,
		     const TString &host,
		     const TString &port)
{
  const char *login_info[5] = { NULL };
  
  /* Make sure that any current connection is closed. */
  Close ();
  
  if (username.Length ()) login_info[0] = username.Data ();
  if (password.Length ()) login_info[1] = password.Data ();
  if (database.Length ()) login_info[2] = database.Data ();
  if (host.Length ()) login_info[3] = host.Data ();
  if (port.Length ()) login_info[4] = port.Data ();
  
  /* Paramaters are: host, port, options, tty, dbname, login, password */
  myConn = PQsetdbLogin (login_info[3], login_info[4], NULL, NULL,
			 login_info[2], login_info[0], login_info[1]);
  
  if (myConn)
    {
      switch (PQstatus (myConn))
	{
	case CONNECTION_OK:
	  return;
	  
	default:
	  myErrorMessage = PQerrorMessage (myConn);
	  Close ();
	  return;
	}
    }
  
  myErrorMessage = "Fatal database error!";
}


void
TDBConnection::Close ()
{
  if (myConn)
    {
      PQfinish (myConn);
      myConn = 0;
    }
}

#endif //HAVE_POSTGRESQL
