#ifndef _T_DB_CONNECTION_HH
#define _T_DB_CONNECTION_HH

#include <libpq-fe.h>
#include "TString.hh"
#include "TDBResult.hh"


/**
 * Manages a database connection.
 * Currently only PostgreSQL is supported.
 *
 * @author Johan Bolmsjo <johan@nocrew.org>
 */

class TDBConnection
{
public:
  
  /**
   * Query if connection is valid.
   *
   * @return  true, false
   */
  inline bool IsValid () { return myConn; }
  
  /**
   * Get error message string.
   *
   * @return  Error message.
   */
  inline TString& ErrorMessage () { return myErrorMessage; }
  
  /**
   * Execute SQL statement.
   * The return object must be destroyed after use.
   *
   * @return  Result object.
   */
  TDBResult* Execute (const TString& command);
  
  
private:
  
  /* Only the connection manager can create connections. */
  friend class TDBConnectionManager;

  /* FIXME: No copying for now! */
  TDBConnection (const TDBConnection&);
  TDBConnection& operator=(const TDBConnection&);
  
  TDBConnection ();
  
  ~TDBConnection () { Close (); }
  
  /**
   * Open database connection.
   * Use IsValid() to check for errors.
   */
  void Open (const TString &username,
	     const TString &password,
	     const TString &database,
	     const TString &host,
	     const TString &port);
  
  /**
   * Close database connection.
   */
  void Close ();
  
  
  /* PostgreSQL connection */
  PGconn* myConn;
  
  /* Contains error message */
  TString myErrorMessage;
};

#endif // _T_DB_CONNECTION_HH
