#ifndef _T_DB_CONNECTION_MANAGER_HH
#define _T_DB_CONNECTION_MANAGER_HH

#include "TString.hh"
#include "TDBConnection.hh"


/**
 * Manages a pool of database connections.
 * Currently only PostgreSQL is supported.
 *
 * FIXME: Only one connection implemented!
 *
 * @author Johan Bolmsjo <johan@nocrew.org>
 */

class TDBConnectionManager
{
public:
  
  /**
   * Initialise connection manager with login data.
   */
  static void SetLogin (TString username,
			TString password,
			TString database,
			TString host,
			TString port);
  
  /**
   * Get connection.
   * The returned object should not be destroyed.
   *
   * @param index  Connection number.
   * @return       Connection pointer.
   */
  static TDBConnection* Connection (int index = 0);
  
  /**
   * Close open connections.
   * To be called at the end of the program.
   */
  static void Close ();
  
  
private:
  
  /* This is an all static class. */
  TDBConnectionManager () {}
  ~TDBConnectionManager () {}
  
  /* Database login information. */
  static TString myUsername;
  static TString myPassword;
  static TString myDatabase;
  static TString myHost;
  static TString myPort;
  
  /* Default connection. */
  static TDBConnection *myConn;
};

#endif // _T_DB_CONNECTION_MANAGER_HH
