#include "universe.h"
#ifdef HAVE_POSTGRESQL

#include "TDBResult.hh"


TDBResult::~TDBResult ()
{
  if (myErrorMessage)
    delete myErrorMessage;
  
  if (myValue)
    delete myValue;
  
  if (myResult)
    PQclear (myResult);
}


TString&
TDBResult::ErrorMessage ()
{
  /* Create error message when needed to minimize string construction
     overhead. */
  if (! myErrorMessage)
    myErrorMessage = new TString ();
  
  return *myErrorMessage;
}


TString&
TDBResult::Value (int tuple, int field)
{
  const char* value = PQgetvalue (myResult, tuple, field);
  
  if (! myValue)
    myValue = new TString (value);
  else
    *myValue = value;
  
  return *myValue;
}


TString*
TDBResult::Value2 (int tuple, int field)
{
  const char* value = PQgetvalue (myResult, tuple, field);
  return new TString (value);
}


TDBResult::TDBResult (PGresult* result)
  : myErrorMessage (0),
    myValue (0),
    myResult (result),
    myTuples (0),
    myFields (0)
{
  char *str;
  int len;
  
  if (! myResult)
    {
      myErrorMessage = new TString ("Fatal database error!");
    }
  else
    {
      switch (PQresultStatus (myResult))
        {
        case PGRES_COMMAND_OK:
	  break;
	  
        case PGRES_TUPLES_OK:
	  myTuples = PQntuples (myResult);
	  myFields = PQnfields (myResult);
          break;
          
        default:
	  /* Strip trailing newline character from message. */
	  str = PQresultErrorMessage (myResult);
	  len = TString::Length (str);
	  
          myErrorMessage = new TString (str, len - 1);
          PQclear (myResult);
	  myResult = 0;
        }
    }
}

#endif //HAVE_POSTGRESQL
