#include <string.h>
#include "Timer.hh"
#include "TString.hh"


void
PerfStringA (Timer& timer)
{
  TString *str;
  int loops, bogo_mips = timer.BogoMips ();
  
  loops = bogo_mips * 10000;
  printf ("Construction and destruction with default CTOR.\n");
  
  timer.Reset ();
  for (int i = 0; i < loops; i++)
    {
      str = new TString;
      delete str;
    }
  timer.LoopsPerSec (loops);
}


void
PerfStringB (Timer& timer)
{
  TString src ("Last Action Hero"), *str;
  int loops, bogo_mips = timer.BogoMips ();
  
  loops = bogo_mips * 10000;
  printf ("Construction and destruction with copy CTOR.\n");
  
  timer.Reset ();
  for (int i = 0; i < loops; i++)
    {
      str = new TString (src);
      delete str;
    }
  timer.LoopsPerSec (loops);
}


void
PerfStringC (Timer& timer)
{
  TString *str;
  int loops, bogo_mips = timer.BogoMips ();
  
  loops = bogo_mips * 5000;
  printf ("Construction and destruction with 16 bytes null terminated "
	  "character string.\n");
  
  timer.Reset ();
  for (int i = 0; i < loops; i++)
    {
      str = new TString ("Last Action Hero");
      delete str;
    }
  timer.LoopsPerSec (loops);
}


void
PerfStringD (Timer& timer)
{
  TString *str;
  int loops, bogo_mips = timer.BogoMips ();
  
  loops = bogo_mips * 5000;
  printf ("Construction and destruction with 64 bytes null terminated "
	  "character string.\n");
  
  timer.Reset ();
  for (int i = 0; i < loops; i++)
    {
      str = new TString ("Last Action Hero"
			 "Last Action Hero"
			 "Last Action Hero"
			 "Last Action Hero");
      delete str;
    }
  timer.LoopsPerSec (loops);
}


void
PerfStringE (Timer& timer)
{
  TString *str;
  int loops, bogo_mips = timer.BogoMips ();
  
  loops = bogo_mips * 5000;
  printf ("Construction and destruction with 16 bytes length specified "
	  "character string.\n");
  
  timer.Reset ();
  for (int i = 0; i < loops; i++)
    {
      str = new TString ("Last Action Hero", 16);
      delete str;
    }
  timer.LoopsPerSec (loops);
}


void
PerfStringF (Timer& timer)
{
  TString *str;
  int loops, bogo_mips = timer.BogoMips ();
  
  loops = bogo_mips * 5000;
  printf ("Construction and destruction with 64 bytes length specified "
	  "character string.\n");
  
  timer.Reset ();
  for (int i = 0; i < loops; i++)
    {
      str = new TString ("Last Action Hero"
			 "Last Action Hero"
			 "Last Action Hero"
			 "Last Action Hero", 16);
      delete str;
    }
  timer.LoopsPerSec (loops);
}


void
PerfStringG (Timer& timer)
{
  TString str1 ("Last Action Hero"
		"Last Action Hero"
		"Last Action Hero"
		"Last Action Hero");
  TString str2 (str1);
  int loops;
  
  loops = timer.BogoMips () * 1000000;
  printf ("Comparing two identical 64 bytes strings.\n");
  
  timer.Reset ();
  for (int i = 0; i < loops;)
    {
      if (str1 == str2)
	i++;
    }
  timer.LoopsPerSec (loops);
}


void
PerfStringH (Timer& timer)
{
  TString *str[1000];
  TString null;
  char buf[10];
  int loops;
  
  loops = timer.BogoMips () * 1000000;
  
  //timer.Reset ();
  for (int i = 0; i < 1000; i++)
    {
      sprintf (buf, "%d", i);
      str[i] = new TString (buf);
    }
  
  for (int i = 0; i < 1000; i++)
    {
      delete  str[i];
    }
  
  TString::PrintStatus ();
  
  //timer.LoopsPerSec (loops);
}
