/* Test all functions of TValVectorT

These are tested implicitly:
  CTOR ()
  CTOR (int)
*/

#include <stdio.h>
#include "TValVectorT.hh"
#include "TString.hh"


void
header (char *cs)
{
  printf ("-- %s\n", cs);
}


void
apply (TString *s, void *)
{
  s->Print ();
}


int
main ()
{
  // Default CTOR / Append / Apply
  TValVectorT<TString> v0;
  v0.Append ("Donald");
  v0.Append ("Duck");
  header ("Default CTOR / Append / Apply");
  v0.Apply (apply);
  
  // CTOR with initial size
  TValVectorT<TString> v1 (4);
  header ("CTOR with initial size");
  v1.Apply (apply);
  
  // CTOR with initial size and value
  TValVectorT<TString> v2 (4, "Goofy");
  header ("CTOR with initial size and value");
  v2.Apply (apply);
  
  // Copy CTOR
  TValVectorT<TString> v3 (v0);
  header ("Copy CTOR");
  v3.Apply (apply);
  
  // Index operator / Entry assignment
  for (int i = 0; i < 4; i++)
    v1[i] = v0[i & 1];
  
  header ("Index operator / Entry assignment");
  v1.Apply (apply);
  
  // Vector assignment
  v3 = v1;
  header ("Vector assignment");
  v3.Apply (apply);
  
  // Resize shrink
  v3.Resize (1);
  header ("Resize shrink");
  v3.Apply (apply);
  
  // Resize grow
  v3.Resize (3);
  header ("Resize grow");
  v3.Apply (apply);
  
  // Resize grow with value
  v3.Resize (5, "Pluto");
  header ("Resize grow with value");
  v3.Apply (apply);
  
  // Clear
  v3.Clear ();
  header ("Clear");
  v3.Apply (apply);
  
  // Entries
  header ("Entries");
  printf ("%d\n", v2.Entries ());
  
  return 0;
}
